@@ -3,6 +3,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
+#include <strings.h>
 #include <sys/stat.h>
 #include <sys/types.h>
  
@@ -22,6 +23,7 @@ void save_applet_prefs(YNCtx *app)
 	{
 		fprintf(f,"width=%d\nheight=%d\n",app->applet_x_size,app->applet_y_size);
 		fprintf(f,"bgcolor=%d,%d,%d\n",(app->color).red,(app->color).green,(app->color).blue);
+		fprintf(f,"bgalpha=%d\n",(gint)((app->bg_alpha)*100));
 		fprintf(f,"font=%s\n",app->fontname);
 		fprintf(f,"fontcolor=%d,%d,%d\n",(app->fontcolor).red,(app->fontcolor).green,(app->fontcolor).blue);
 		fclose(f);
@@ -40,6 +42,7 @@ void adjust_settings(YNCtx *app)
 	if(app->applet_y_size>MAX_Y_SIZE)
 		app->applet_y_size=MAX_Y_SIZE;
 
+	app->bg_alpha=1-(app->bg_alpha/100);
 }
 
 void load_applet_prefs(YNCtx *app)
@@ -87,6 +90,7 @@ void load_applet_prefs(YNCtx *app)
 	gdk_color_parse (DEFAULT_FONT_COLOR, &(app->fontcolor));
 	app->fontname=g_new0(gchar,strlen(DEFAULT_FONT)+1);
 	strcpy(app->fontname,DEFAULT_FONT);
+	app->bg_alpha=(gfloat)DEFAULT_BG_ALPHA/100;
 
 	f=g_io_channel_new_file(app->conf_file,"r",NULL);
 
@@ -115,6 +119,13 @@ void load_applet_prefs(YNCtx *app)
 				colormap=gdk_colormap_get_system();
 				gdk_colormap_alloc_color(colormap,&(app->color),TRUE,TRUE);
 			}
+			if(strstr(readbuf,"bgalpha"))
+			{
+				gint alpha;
+				sscanf(readbuf,"bgalpha=%d\n",&alpha);
+				app->bg_alpha=(gfloat)alpha/100;
+				
+			}
 			if(strstr(readbuf,"font="))
 			{
 				fontbuffer=strchr(readbuf,'\n');
@@ -151,7 +162,7 @@ void load_applet_prefs(YNCtx *app)
 void load_note_text(YNCtx *app)
 {
 	FILE *f=NULL;
-	gchar buffer[128];
+	gchar buffer[1024];
 	GtkTextIter start;
 	GtkTextIter end;
 	gint nread=0;
@@ -164,12 +175,13 @@ void load_note_text(YNCtx *app)
 	gtk_text_buffer_get_bounds(GTK_TEXT_BUFFER(app->buffer),&start,&end);
 	gtk_text_buffer_delete (GTK_TEXT_BUFFER(app->buffer),&start,&end);
 	
+	bzero(buffer,1024);
 	f=fopen(note_path,"r");
 	if(f!=NULL)
 	{
 		while(!feof(f))
 		{
-			nread=fread(buffer,1,128,f);
+			nread=fread(buffer,1,1024,f);
 			gtk_text_buffer_get_end_iter(GTK_TEXT_BUFFER(app->buffer),&end);
 			gtk_text_buffer_insert(GTK_TEXT_BUFFER(app->buffer),&end,buffer,nread);
 		}
@@ -184,6 +196,7 @@ void load_note_text(YNCtx *app)
 	label=g_new0(gchar,3);
 	sprintf(label,"%.2i",*app->note_number);
 	gtk_label_set_text (GTK_LABEL(app->label),label);
+
 }
 
 gboolean edit_note(GObject *o,GdkEventButton *event,YNCtx *app)
@@ -282,8 +295,6 @@ int write_buffer_to_file(gchar *buffer,gchar *fn)
 
 gboolean erase_note(GObject *o,GdkEventButton *event,YNCtx *app)
 {
-/*	GtkTextIter	start;
-	GtkTextIter	end;*/
 	GtkWidget	*confirmation;
 	
 	gint response=0;
@@ -293,46 +304,12 @@ gboolean erase_note(GObject *o,GdkEventButton *event,YNCtx *app)
 	gtk_object_destroy(GTK_OBJECT(confirmation));
 	
 	if ( response == GTK_RESPONSE_OK) {
-		g_print("deleting note");
-/*		gtk_text_buffer_get_bounds(GTK_TEXT_BUFFER(app->buffer),&start,&end);
-		gtk_text_buffer_delete (GTK_TEXT_BUFFER(app->buffer),&start,&end);*/
 		gtk_text_buffer_set_text(GTK_TEXT_BUFFER(app->buffer),"",-1);
 	}
 
 	return(TRUE);
 }
 
-gboolean save_note(GObject *o,GdkEventButton *event,YNCtx *app)
-{
-	gboolean result = FALSE;
-	
-	if (*app->locked == FALSE) {
-	  result = save_note_text(app,app->buffer);
-	  result = lock_note(app);
-/*	  gtk_image_set_from_stock(GTK_IMAGE(app->save_image),GTK_STOCK_EDIT,HILDON_ICON_SIZE_SMALL);*/
-	} else {
-	  result = unlock_note(app);
-/*	  gtk_image_set_from_stock(GTK_IMAGE(app->save_image),GTK_STOCK_SAVE,HILDON_ICON_SIZE_SMALL);*/
-	}
-	return(TRUE);
-}
-
-gboolean lock_note(YNCtx *app)
-{
-	*app->locked = TRUE;
-	gtk_text_view_set_editable(GTK_TEXT_VIEW(app->textview),FALSE);
-	gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(app->textview),FALSE);
-	return(TRUE);
-}
-
-gboolean unlock_note(YNCtx *app)
-{
-	*app->locked = FALSE;
-	gtk_text_view_set_editable(GTK_TEXT_VIEW(app->textview),TRUE);
-	gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(app->textview),TRUE);
-	return(TRUE);
-}
-
 gboolean next_note(GObject *o,GdkEventButton *event,YNCtx *app)
 {
 	gboolean result = FALSE;
@@ -391,20 +368,56 @@ void apply_preferences(YNCtx *app)
 
 	app->applet_x_size=atoi(gtk_entry_get_text(GTK_ENTRY(app->entry_width)));
 	app->applet_y_size=atoi(gtk_entry_get_text(GTK_ENTRY(app->entry_height)));
+	app->bg_alpha=hildon_number_editor_get_value(HILDON_NUMBER_EDITOR(app->entry_bg_alpha));
 	adjust_settings(app);
 	
 	gtk_window_resize(GTK_WINDOW(app->parent),app->applet_x_size,app->applet_y_size);
-	gtk_widget_modify_base(app->textview, GTK_STATE_NORMAL, &(app->color));
+/*	gtk_widget_modify_base(app->textview, GTK_STATE_NORMAL, &(app->color));*/
 	gtk_widget_modify_text(app->textview, GTK_STATE_NORMAL, &(app->fontcolor));
 
 	font=pango_font_description_from_string(app->fontname);
 	gtk_widget_modify_font(app->textview,font);
 	pango_font_description_free(font);	
-	
-	save_applet_prefs(app);
+
+	gdk_window_invalidate_rect((app->top)->window,&(app->top)->allocation,TRUE);
+	save_applet_prefs(app);	
 
 }
 
+void set_cairo_transparency(GdkDrawable *drawable, GdkEventExpose *event, GdkColor color, gfloat alpha)
+{
+	cairo_t *cr;
+
+	cr = gdk_cairo_create (drawable);
+	gdk_cairo_region (cr, event->region);
+	cairo_clip (cr);
+
+	cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+	cairo_set_source_rgba (cr, color.red, color.green, color.blue, alpha);
+	cairo_paint (cr);
+  
+	cairo_destroy (cr);
+}
+
+
+static gboolean widget_expose_event(GtkWidget *widget, GdkEventExpose *event, YNCtx *app)
+{
+	set_cairo_transparency(GDK_DRAWABLE(widget->window),event,app->color,app->bg_alpha);
+	return FALSE;
+}
+
+static gboolean textarea_expose_event(GtkWidget *widget, GdkEventExpose *event, YNCtx *app)
+{
+	set_cairo_transparency(GDK_DRAWABLE(widget->window),event,app->color,app->bg_alpha);
+
+	app->textwindow=gtk_text_view_get_window (GTK_TEXT_VIEW (app->textview),GTK_TEXT_WINDOW_TEXT);
+	if (app->textwindow != NULL)
+		set_cairo_transparency(GDK_DRAWABLE(app->textwindow),event,app->color,app->bg_alpha);
+
+	return FALSE;
+}
+
+
 gboolean configure_applet_button(GObject *o,GdkEventButton *event,YNCtx *app)
 {
 	return (configure_applet(NULL,app));
@@ -416,7 +429,6 @@ gboolean configure_applet(GtkWidget *o,YNCtx *app)
 	GtkWidget *hbox=NULL;
 	GtkWidget *label=NULL;
 	GtkWidget *button=NULL;
-/*	GtkWidget *tchooser=NULL;*/
 	GtkWidget *fbutton=NULL;
 	GtkWidget *fcbutton=NULL;
 	gchar value[4];
@@ -463,17 +475,17 @@ gboolean configure_applet(GtkWidget *o,YNCtx *app)
 	gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog)->vbox),hbox);	
 	gtk_widget_show_all(hbox);
 	
-/*	hbox=gtk_hbox_new(TRUE,5);
+	hbox=gtk_hbox_new(TRUE,5);
 		label=gtk_label_new("Transparency:");
 		gtk_container_add (GTK_CONTAINER (hbox),label);
 
-		tchooser=hildon_number_editor_new(0, 100);
-		gtk_widget_set_size_request (GTK_WIDGET(tchooser),150,-1);
-		gtk_container_add(GTK_CONTAINER(hbox),tchooser);
-		
+		app->entry_bg_alpha=hildon_number_editor_new(0, 100);
+		gtk_widget_set_size_request (GTK_WIDGET(app->entry_bg_alpha),150,-1);
+		hildon_number_editor_set_value(HILDON_NUMBER_EDITOR(app->entry_bg_alpha),(gint)(100-(app->bg_alpha*100)));
+		gtk_container_add(GTK_CONTAINER(hbox),app->entry_bg_alpha);
 	gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog)->vbox),hbox);	
 	gtk_widget_show_all(hbox);
-*/
+
 	hbox=gtk_hbox_new(TRUE,5);
 		label=gtk_label_new("Text Font:");
 		gtk_container_add (GTK_CONTAINER (hbox),label);
@@ -507,9 +519,9 @@ gboolean configure_applet(GtkWidget *o,YNCtx *app)
 }
 
 
+
 void build_ui (void)
 {
-
 	PangoFontDescription *font;
 
 	app->frame= gtk_frame_new(NULL);
@@ -530,53 +542,56 @@ void build_ui (void)
 	app->next_evbox=gtk_event_box_new ();
 	gtk_event_box_set_visible_window(GTK_EVENT_BOX(app->next_evbox),FALSE);
 	gtk_container_add (GTK_CONTAINER (app->next_evbox),app->next_image);
-	g_signal_connect(G_OBJECT(app->next_evbox),"button_press_event",G_CALLBACK(next_note),app);
+	g_signal_connect(G_OBJECT(app->next_evbox),"button_release_event",G_CALLBACK(next_note),app);
 	
 	app->previous_image=gtk_image_new_from_stock(GTK_STOCK_GO_BACK,HILDON_ICON_SIZE_SMALL);
 	app->previous_evbox=gtk_event_box_new ();
 	gtk_event_box_set_visible_window(GTK_EVENT_BOX(app->previous_evbox),FALSE);
 	gtk_container_add (GTK_CONTAINER (app->previous_evbox),app->previous_image);
-	g_signal_connect(G_OBJECT(app->previous_evbox),"button_press_event",G_CALLBACK(previous_note),app);
+	g_signal_connect(G_OBJECT(app->previous_evbox),"button_release_event",G_CALLBACK(previous_note),app);
 	
 	app->delete_image=gtk_image_new_from_stock(GTK_STOCK_DELETE,HILDON_ICON_SIZE_SMALL);
 	app->delete_evbox=gtk_event_box_new ();
 	gtk_event_box_set_visible_window(GTK_EVENT_BOX(app->delete_evbox),FALSE);
 	gtk_container_add (GTK_CONTAINER (app->delete_evbox),app->delete_image);
-	g_signal_connect(G_OBJECT(app->delete_evbox),"button_press_event",G_CALLBACK(erase_note),app);
+	g_signal_connect(G_OBJECT(app->delete_evbox),"button_release_event",G_CALLBACK(erase_note),app);
 	
 	app->save_image=gtk_image_new_from_stock(GTK_STOCK_EDIT,HILDON_ICON_SIZE_SMALL);
 	app->save_evbox=gtk_event_box_new ();
 	gtk_event_box_set_visible_window(GTK_EVENT_BOX(app->save_evbox),FALSE);
 	gtk_container_add (GTK_CONTAINER (app->save_evbox),app->save_image);
-	g_signal_connect(G_OBJECT(app->save_evbox),"button_press_event",G_CALLBACK(edit_note),app);
+	g_signal_connect(G_OBJECT(app->save_evbox),"button_release_event",G_CALLBACK(edit_note),app);
 	
 	app->label=gtk_label_new("00");
 
 	app->scrolledwindow=GTK_SCROLLED_WINDOW(gtk_scrolled_window_new(NULL,NULL));
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(app->scrolledwindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	/*gtk_object_set(GTK_OBJECT(app->scrolledwindow),"scrollbar-spacing",0,NULL);*/
-	
-	gchar *parseString=g_strconcat("style \"my-style\"\n","{\n","GtkScrolledWindow::scrollbar-spacing = 0\n","}\n","class \"GtkScrolledWindow\" style \"my-style\"\n",NULL);
-	gtk_rc_parse_string(parseString);
+	app->vscroll=gtk_scrolled_window_get_vscrollbar(app->scrolledwindow);
+	gtk_widget_set_app_paintable(app->vscroll,TRUE);
+	g_signal_connect(G_OBJECT(app->vscroll),"expose-event",G_CALLBACK(widget_expose_event),app);
+
+	gtk_rc_parse_string(scroll_style);
 	gtk_rc_reset_styles(gtk_settings_get_for_screen(gdk_screen_get_default()));
-	/*gtk_widget_set_size_request ( GTK_WIDGET ((app->scrolledwindow)->vscrollbar), 10, -1 );*/
+/*	gtk_widget_set_size_request ( GTK_WIDGET ((app->scrolledwindow)->vscrollbar), 10, -1 );*/
 
 	app->textview=gtk_text_view_new();
 	gtk_text_view_set_editable(GTK_TEXT_VIEW(app->textview),TRUE);
 	gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(app->textview),TRUE);
 	gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(app->textview),GTK_WRAP_WORD);
 
-	gtk_widget_modify_base(app->textview, GTK_STATE_NORMAL, &(app->color));
-	gtk_widget_modify_text(app->textview, GTK_STATE_NORMAL, &(app->fontcolor));
-
 	font=pango_font_description_from_string(app->fontname);
 	gtk_widget_modify_font(app->textview,font);
 	pango_font_description_free(font);	
 
 	app->buffer=gtk_text_view_get_buffer(GTK_TEXT_VIEW(app->textview));
 
+	gtk_widget_modify_text(app->textview, GTK_STATE_NORMAL, &(app->fontcolor));
+	font=pango_font_description_from_string(app->fontname);
+	gtk_widget_modify_font(app->textview,font);
+	pango_font_description_free(font);	
+
 	gtk_box_pack_start(GTK_BOX(app->vbox),app->top,FALSE,FALSE,0);
-	gtk_box_pack_end(GTK_BOX(app->top),app->conf_evbox,FALSE,FALSE,2);
+/*	gtk_box_pack_end(GTK_BOX(app->top),app->conf_evbox,FALSE,FALSE,2);*/
 	gtk_box_pack_end(GTK_BOX(app->top),app->delete_evbox,FALSE,FALSE,2);
 	gtk_box_pack_end(GTK_BOX(app->top),app->save_evbox,FALSE,FALSE,2);
 	gtk_box_pack_end(GTK_BOX(app->top),app->next_evbox,FALSE,FALSE,2);
@@ -586,15 +601,19 @@ void build_ui (void)
 	gtk_container_add (GTK_CONTAINER (app->vbox), GTK_WIDGET(app->scrolledwindow));
 	gtk_container_add (GTK_CONTAINER (app->scrolledwindow),app->textview);
 
+ 	gtk_container_set_border_width (GTK_CONTAINER (app->textview), 0);
+  	gtk_container_set_border_width (GTK_CONTAINER (app->scrolledwindow), 0);
   	gtk_container_set_border_width (GTK_CONTAINER (app->frame), 0);
 
+	g_signal_connect(G_OBJECT(app->textview),"expose-event",G_CALLBACK(textarea_expose_event),app);
   	app->align = gtk_alignment_new (0.5,0.5,1.0,1.0);
 
   	gtk_container_add (GTK_CONTAINER (app->frame), app->align);
 	gtk_container_add( GTK_CONTAINER( app->align ), app->vbox );
 
 	gtk_widget_show_all (GTK_WIDGET (app->frame)); 
-
+	
+	
 }
 
 static void yellownotes_plugin_init (YellowNotesPlugin *desktop_plugin)
@@ -618,7 +637,42 @@ static void yellownotes_plugin_init (YellowNotesPlugin *desktop_plugin)
 	app->parent=desktop_plugin;
 } 
 
-static void yellownotes_plugin_class_init (YellowNotesPluginClass *class) {} 
+static void yellownotes_plugin_class_init (YellowNotesPluginClass *class) {
+        GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (class);
+
+        widget_class->realize = yellownotes_plugin_realize;
+	widget_class->expose_event = yellownotes_plugin_expose_event;
+} 
 
 static void yellownotes_plugin_class_finalize (YellowNotesPluginClass *class) {} 
 
+static void yellownotes_plugin_realize (GtkWidget *widget)
+{
+        GdkScreen *screen;
+
+        screen = gtk_widget_get_screen (widget);
+        gtk_widget_set_colormap (widget,gdk_screen_get_rgba_colormap (screen));
+
+        gtk_widget_set_app_paintable (widget,TRUE);
+
+        GTK_WIDGET_CLASS (yellownotes_plugin_parent_class)->realize (widget);
+
+}
+
+static gboolean yellownotes_plugin_expose_event(GtkWidget *widget, GdkEventExpose *event)
+{
+	cairo_t *cr;
+
+	cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
+	gdk_cairo_region (cr, event->region);
+	cairo_clip (cr);
+
+	cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+	cairo_set_source_rgba (cr, (app->color).red, (app->color).green, (app->color).blue, app->bg_alpha);
+	cairo_paint (cr);
+  
+	cairo_destroy (cr);
+
+	return GTK_WIDGET_CLASS (yellownotes_plugin_parent_class)->expose_event (widget,event);
+
+}
