@@ -30,18 +30,19 @@ G_BEGIN_DECLS
 #define APPLET_Y_SIZE 200
 #define TOOLBAR_Y_SIZE 22
 
-#define MIN_X_SIZE 120
+#define MIN_X_SIZE 140
 #define MAX_X_SIZE 680
-#define MIN_Y_SIZE 100
+#define MIN_Y_SIZE 140
 #define MAX_Y_SIZE 400
 
 #define SETTINGS_PATH	".yellownotes"
 #define EXISTING_NOTE	"note"
 #define PREFS_FILE	"yellownotes.conf"
 
-#define DEFAULT_COLOR		"#ffff99"
+#define DEFAULT_COLOR		"#ffff00"
 #define DEFAULT_FONT_COLOR	"#000000"
 #define DEFAULT_FONT		"Sans 12"
+#define DEFAULT_BG_ALPHA	50
 
 
 
@@ -79,7 +80,8 @@ GType yellownotes_plugin_get_type(void);
 
 HD_DEFINE_PLUGIN_MODULE (YellowNotesPlugin, yellownotes_plugin, HD_TYPE_HOME_PLUGIN_ITEM);
 
-
+static void yellownotes_plugin_realize (GtkWidget *widget);
+static gboolean yellownotes_plugin_expose_event(GtkWidget *widget, GdkEventExpose *event);
 
 
 typedef struct
@@ -106,14 +108,18 @@ typedef struct
 	GtkWidget *label;
 
 	GtkWidget *textview;
+	GdkWindow *textwindow;
 	GtkTextBuffer *buffer;
 	GtkScrolledWindow *scrolledwindow;
+	GtkWidget *vscroll;
 	
 	GtkWidget *entry_width;
 	GtkWidget *entry_height;
+	GtkWidget *entry_bg_alpha;
 	GdkColor color;
 	GdkColor fontcolor;
 	gchar *fontname;
+	gfloat bg_alpha;
 	
 	gchar *prefs_dir;
 	gchar *conf_file;
@@ -148,12 +154,6 @@ gboolean save_note_text(YNCtx *app,GtkTextBuffer *buffer);
 /*callback used to edit note content in dialog*/
 gboolean edit_note(GObject *o,GdkEventButton *event,YNCtx *app);
 
-/*callback to lock editing mode in applet.  --not required in fremantle-- */
-gboolean lock_note(YNCtx *app);
-
-/*callback to unlock editing mode in applet --not required in fremantle--*/
-gboolean unlock_note(YNCtx *app);
-
 /*callback to switch to next note (right arrow)*/
 gboolean next_note(GObject *o,GdkEventButton *event,YNCtx *app);
 
@@ -163,9 +163,6 @@ gboolean previous_note(GObject *o,GdkEventButton *event,YNCtx *app);
 /*callback to erase note content (trashcan button)*/
 gboolean erase_note(GObject *o,GdkEventButton *event,YNCtx *app);
 
-/*callback to save note (save button) --not used in fremant--*/
-gboolean save_note(GObject *o,GdkEventButton *event,YNCtx *app);
-
 /*callback to get background color selection*/
 void select_bg_color(GObject *o, YNCtx *app);
 
@@ -175,6 +172,9 @@ void select_font(GObject *o, YNCtx *app);
 /*callback to get font color selection*/
 void select_font_color(GObject *o, YNCtx *app);
 
+/*function to apply color and alpha value to widget using cairo*/
+void set_cairo_transparency(GdkDrawable *drawable, GdkEventExpose *event, GdkColor color, gfloat alpha);
+
 /*callback to apply preferences once user changes values in settings dialog*/
 void apply_preferences(YNCtx *app);
 
@@ -188,6 +188,28 @@ gboolean configure_applet(GtkWidget *o,YNCtx *app);
 void mkplugin_create_home_applet(YNCtx *app);
 void build_ui(void);
 
+/*widget style to unset sapwood engine for scrollbar.
+RGBA colormap has conflict with default theme's PNGs*/
+gchar *scroll_style="style \"my-style\" \
+{ \
+	bg[NORMAL] = \"#666666\" \
+	bg[ACTIVE] = \"#000000\" \
+        GtkRange::stepper_size = 26 \
+        GtkRange::stepper_spacing = 0 \
+        GtkRange::trough_border = 0 \
+        GtkRange::slider_width = 20 \
+        GtkRange::draw_trough_under_steppers = 0 \
+        GtkRange::draw_trough = 0 \
+        GtkRange::arrow_displacement_x = 0 \
+        GtkRange::arrow_displacement_y = 0 \
+        GtkRange::autodimmed_steppers = 1 \
+        GtkScrollbar::min-slider-length = 32 \
+	GtkScrollbar::scrollbar-spacing = 0 \
+        GtkRange::activate-slider = 1 \
+	engine \"\" { } \
+} \
+class \"GtkScrollbar\" style \"my-style\"";
+
 G_END_DECLS
 
 #endif
